from typing import Final

ENTRYPOINT_PARAMS: Final = {
    "default": "/app",
    "envvar": "JETPACK_ENTRYPOINT",
    "help": "Path to user entrypoint that should be loaded. Can be file or directory. If directory, then we assume filename is main.py or jetpack_main.py.",
    "show_default": True,
}



from typing import Any, Awaitable, Callable, TypeVar, cast

from jetpack._task.jetpack_function import JetpackFunction
from jetpack._task.jetpack_function_with_client import schedule as schedule
from jetpack.config import symbols

T = TypeVar("T")


# @function is our general remote work decorator. It does not specify how the
# work will be done (RPC, job, queue, etc) and instead leaves that as an
# implementation detail.
def function(fn: Callable[..., T]) -> Callable[..., Awaitable[T]]:
    task: JetpackFunction[T] = JetpackFunction(fn)
    symbols.get_symbol_table().register(fn)
    return task


jet = function
jetroutine = function
